unit emw;
(**********************************************************************
 *
 * Filename:    emw.pas
 *
 * Copyright:   Pico Technology Limited 2002
 *
 * Author:      Martin Berriman
 *
 * Description:
 *   This file demonstrates how to use the enviromon driver from within
 *   a Delphi application.
 *
 * History:
 *  06Mar02 MPB Created
 *
**********************************************************************)

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TForm1 = class(TForm)
    Sensor1Box: TEdit;
    Sensor2Box: TEdit;
    OpenBtn: TButton;
    CloseBtn: TButton;
    GetCurrentBtn: TButton;
    GroupBox1: TGroupBox;
    GetHistoricalBtn: TButton;
    HistoricalBox: TListBox;
    Label1: TLabel;
    Label2: TLabel;
    procedure OpenBtnClick(Sender: TObject);
    procedure CloseBtnClick(Sender: TObject);
    procedure GetCurrentBtnClick(Sender: TObject);
    procedure GetHistoricalBtnClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

const TAB = #9;

var
  Form1: TForm1;
  no_of_sensors : Integer;

implementation

{$A-}
{$R *.DFM}
{$I emwdll.inc}

procedure TForm1.OpenBtnClick(Sender: TObject);
begin
     em_open(PChar('envimon.ini'));
     OpenBtn.Enabled := False;
     CloseBtn.Enabled := True;
     GetCurrentBtn.Enabled := True;
     GetHistoricalBtn.Enabled := True;
end;

procedure TForm1.CloseBtnClick(Sender: TObject);
begin
     em_close;
     CloseBtn.Enabled := False;
     GetCurrentBtn.Enabled := False;
     GetHistoricalBtn.Enabled := False;
     OpenBtn.Enabled := True;
     HistoricalBox.Clear;
     Sensor1Box.Text := '';
     Sensor2Box.Text := '';
end;

procedure TForm1.GetCurrentBtnClick(Sender: TObject);
var  Current : array [0..MAX_SENSORS-1] of Word;
begin
     //Get the current readings - may take a few calls before you see results

     //Check how many sensors there are
     no_of_sensors := em_get_sensors;

     em_get_current(Current);
     Sensor1Box.Text := FloatToStrF(Current[0]/100, ffFixed, 5, 2);
     Sensor2Box.Text := FloatToStrF(Current[1]/100, ffFixed, 5, 2);
end;


procedure TForm1.GetHistoricalBtnClick(Sender: TObject);
var NumReadings, i : Integer;
    S : String;
    Historical : array [0..MAX_SENSORS-1] of READING;
begin
     HistoricalBox.Clear;
     S := 'Reading' + TAB + 'Sensor1' + TAB + 'Sensor2';
     HistoricalBox.Items.Add(S);

     //Check how many sensors there are
     no_of_sensors := em_get_sensors;

     (*Ask for 60 readings ...
       if fewer are available, no_available will be less than 60

       the time interval will depend on sample rate
       if sample interval is one minute, 60 readings is an hour's data

       This also fixes the 'start point' for the requested set of readings
     *)

     NumReadings := em_open_reading(60);
     for i := 0 to NumReadings-1 do
     begin
          em_get_reading(Historical, i);
          S := IntToStr(i);
          S := S + TAB;
          S := S + FloatToStrF(Historical[0].temperature/100, ffFixed, 5, 2);
          S := S + TAB;
          S := S + FloatToStrF(Historical[1].temperature/100, ffFixed, 5, 2);
          HistoricalBox.Items.Add(S);
     end;
     em_close_reading;
end;

procedure TForm1.FormClose(Sender: TObject; var Action: TCloseAction);
begin
     if CloseBtn.Enabled = True then CloseBtn.Click;
end;

end.
